@@ -138,6 +138,9 @@ namespace abclass
         double lambda_max_;
         arma::vec lambda_;        // lambda sequence
         arma::vec group_weight_;  // adaptive weights for each group
+        // did user specified a customized lambda sequence?
+        bool custom_lambda_ = false;
+        double lambda_min_ratio_ = 0.01;
 
         // estimates
         arma::cube coef_;         // p1_ by km1_
@@ -233,10 +236,11 @@ namespace abclass
     {
         double ell_verbose { 0.0 }, obj_verbose { 0.0 }, reg_verbose { 0.0 };
         if (verbose > 2) {
-            Rcpp::Rcout << "\nStarting values of beta:\n";
-            Rcpp::Rcout << beta << "\n";
-            Rcpp::Rcout << "The active set of beta:\n";
-            Rcpp::Rcout << arma2rvec(is_active) << "\n";
+            Rcpp::Rcout << "\nStarting values of beta:\n"
+                        << beta << "\n"
+                        << "\nThe active set of beta:\n"
+                        << arma2rvec(is_active)
+                        << "\n";
         };
         if (verbose > 1) {
             obj_verbose = objective0(inner);
@@ -248,17 +252,17 @@ namespace abclass
                 continue;
             }
             arma::rowvec old_beta_j { beta.row(j) };
-            double gamma_j { gmd_lowerbound_(j) };
+            double mj { gmd_lowerbound_(j) };
             arma::rowvec uj {
-                - gmd_gradient(inner, j) + gamma_j * beta.row(j)
+                - gmd_gradient(inner, j) + mj * beta.row(j)
             };
-            double wj { group_weight_(j) } ;
-            double pos_part { 1 - lambda * wj / l2_norm(uj) };
+            double lambda_j { lambda * group_weight_(j) };
+            double pos_part { 1 - lambda_j / l2_norm(uj) };
             // update beta
-            if (is_le(pos_part, 0.0)) {
+            if (pos_part <= 0.0) {
                 beta.row(j) = arma::zeros<arma::rowvec>(km1_);
             } else {
-                beta.row(j) = uj * pos_part / gamma_j;
+                beta.row(j) = uj * pos_part / mj;
             }
             for (size_t i {0}; i < n_obs_; ++i) {
                 inner(i) += x_(i, j) *
@@ -330,7 +334,7 @@ namespace abclass
                 run_one_active_cycle(beta, inner, is_active,
                                      lambda, true, verbose);
                 // check two active sets coincide
-                if (is_gt(l1_norm(is_active_varying - is_active), 0)) {
+                if (l1_norm(is_active_varying - is_active) > 0) {
                     // if different, repeat this process
                     if (verbose > 1) {
                         Rcpp::Rcout << "Changed the active set from "
@@ -350,6 +354,8 @@ namespace abclass
                         Rcpp::Rcout << "Converged over the active set after "
                                     << num_iter_ + 1
                                     << " iteration(s)\n";
+                        Rcpp::Rcout << "The size of active set is "
+                                    << l1_norm(is_active) << "\n";
                     }
                     num_iter_ = i + 1;
                     break;
@@ -397,7 +403,7 @@ namespace abclass
         // set group weight
         set_group_weight(group_weight);
         arma::uvec penalty_group { arma::find(group_weight_ > 0.0) };
-        arma::uvec penalty_free { arma::find(group_weight_ <= 0.0) };
+        arma::uvec penalty_free { arma::find(group_weight_ == 0.0) };
         // record control
         epsilon_ = epsilon;
         max_iter_ = max_iter;
@@ -426,8 +432,10 @@ namespace abclass
                                log_lambda_max + std::log(lambda_min_ratio),
                                nlambda)
                 );
+            lambda_min_ratio_ = lambda_min_ratio;
         } else {
             lambda_ = arma::reverse(arma::unique(lambda));
+            custom_lambda_ = true;
         }
         // initialize the estimate cube
         coef_ = arma::cube(p1_, km1_, lambda_.n_elem, arma::fill::zeros);
@@ -458,14 +466,14 @@ namespace abclass
             one_grad_beta = gradient(one_inner);
             for (arma::uvec::iterator it { penalty_group.begin() };
                  it != penalty_group.end(); ++it) {
+                if (is_active_strong(*it) > 0) {
+                    continue;
+                }
                 double one_strong_lhs { l2_norm(one_grad_beta.row(*it)) };
                 one_strong_rhs = group_weight_(*it) *
                     (2 * lambda_li - old_lambda);
                 if (one_strong_lhs >= one_strong_rhs) {
                     is_active_strong(*it) = 1;
-                } else {
-                    is_active_strong(*it) = 0;
-                    one_beta.row(*it) = arma::zeros<arma::rowvec>(km1_);
                 }
             }
             old_lambda = lambda_li;
@@ -487,7 +495,7 @@ namespace abclass
                 // check kkt condition
                 for (arma::uvec::iterator it { penalty_group.begin() };
                      it != penalty_group.end(); ++it) {
-                    if (is_active_strong(*it) > 0) {
+                    if (is_active_strong_old(*it) > 0) {
                         continue;
                     }
                     if (l2_norm(gmd_gradient(one_inner, *it)) >
@@ -497,14 +505,16 @@ namespace abclass
                     }
                 }
                 if (arma::accu(is_strong_rule_failed) > 0) {
-                    is_active_strong = is_active_strong_old +
+                    is_active_strong = is_active_strong_old ||
                         is_strong_rule_failed;
                     if (verbose > 0) {
-                        Rcpp::Rcout << "The strong rule failed.\n"
-                                    << "The size of old active set: ";
-                        Rcpp::Rcout << l1_norm(is_active_strong_old) << "\n";
-                        Rcpp::Rcout << "The size of new active set: ";
-                        Rcpp::Rcout << l1_norm(is_active_strong) << "\n";
+                        Rcpp::Rcout << "The strong rule failed for "
+                                    << arma::accu(is_strong_rule_failed)
+                                    << " group(s)\nThe size of old active set: "
+                                    << l1_norm(is_active_strong_old)
+                                    << "\nThe size of new active set: "
+                                    << l1_norm(is_active_strong)
+                                    << "\n";
                     }
                 } else {
                     if (verbose > 0) {
