@@ -73,22 +73,19 @@ namespace abclass
 
     public:
 
-        // inherit constructors
+        // inherit default constructors
         using AbclassNet::AbclassNet;
 
         //! @param x The design matrix without an intercept term.
         //! @param y The category index vector.
         HingeBoostNet(const arma::mat& x,
                       const arma::uvec& y,
-                      const double lum_c = 0.0,
                       const bool intercept = true,
                       const bool standardize = true,
                       const arma::vec& weight = arma::vec()) :
             AbclassNet(x, y, intercept, standardize, weight)
         {
-            set_lum_c(lum_c);
-            // set the CMD lowerbound (which needs to be done only once)
-            // set_cmd_lowerbound();
+            set_lum_c(0.0);
         }
 
         HingeBoostNet* set_lum_c(const double lum_c)
