@@ -32,18 +32,20 @@ Rcpp::List rcpp_hinge_boost_net(
     const bool standardize = true,
     const unsigned int nfolds = 0,
     const bool stratified_cv = true,
-    const unsigned int max_iter = 1e5,
-    const double epsilon = 1e-4,
+    const unsigned int alignment = 0,
+    const unsigned int maxit = 1e5,
+    const double epsilon = 1e-3,
     const bool varying_active_set = true,
     const double lum_c = 0.0,
     const unsigned int verbose = 0
     )
 {
     abclass::HingeBoostNet object {
-        x, y, lum_c, intercept, standardize, weight
+        x, y, intercept, standardize, weight
     };
+    object.set_lum_c(lum_c);
     return abclass_net_fit(object, y,
                            lambda, alpha, nlambda, lambda_min_ratio,
-                           nfolds, stratified_cv, max_iter, epsilon,
-                           varying_active_set, verbose);
+                           nfolds, stratified_cv, alignment,
+                           maxit, epsilon, varying_active_set, verbose);
 }
