@@ -32,8 +32,9 @@ Rcpp::List rcpp_logistic_net(
     const bool standardize = true,
     const unsigned int nfolds = 0,
     const bool stratified_cv = true,
-    const unsigned int max_iter = 1e5,
-    const double epsilon = 1e-4,
+    const unsigned int alignment = 0,
+    const unsigned int maxit = 1e5,
+    const double epsilon = 1e-3,
     const bool varying_active_set = true,
     const unsigned int verbose = 0
     )
@@ -43,6 +44,6 @@ Rcpp::List rcpp_logistic_net(
     };
     return abclass_net_fit(object, y,
                            lambda, alpha, nlambda, lambda_min_ratio,
-                           nfolds, stratified_cv, max_iter, epsilon,
-                           varying_active_set, verbose);
+                           nfolds, stratified_cv, alignment,
+                           maxit, epsilon, varying_active_set, verbose);
 }
